@@ -25,7 +25,7 @@ from paho.mqtt.client import Client  as ClientMQTT
 from paho.mqtt import publish as MQTTPublish
 from paho.mqtt import subscribe as MQTTSubscribe
 
-_LOGGER = logging.getLogger(__name__)
+#_LOGGER = logging.getLogger(__name__)
 
 # These consts define all of the vocabulary used by this library when presenting various states and components.
 # Applications implementing this library should import these rather than hard-code the strings, for future-proofing.
@@ -195,7 +195,7 @@ class EcoVacsAPI:
         }
         
         self.verify_ssl = str_to_bool_or_cert(verify_ssl)
-        _LOGGER.debug("Setting up EcoVacsAPI")
+        #_LOGGER.debug("Setting up EcoVacsAPI")
         self.resource = device_id[0:8]
         self.country = country
         self.continent = continent
@@ -229,34 +229,34 @@ class EcoVacsAPI:
         return result
 
     def __call_main_api(self, function, *args):
-        _LOGGER.debug("calling main api {} with {}".format(function, args))
+        #_LOGGER.debug("calling main api {} with {}".format(function, args))
         params = OrderedDict(args)
         params['requestId'] = self.md5(time.time())
         url = (EcoVacsAPI.MAIN_URL_FORMAT + "/" + function).format(**self.meta)
         api_response = requests.get(url, self.__sign(params), verify=self.verify_ssl)
         json = api_response.json()
-        _LOGGER.debug("got {}".format(json))
+        #_LOGGER.debug("got {}".format(json))
         if json['code'] == '0000':
             return json['data']
         elif json['code'] == '1005':
-            _LOGGER.warning("incorrect email or password")
+            #_LOGGER.warning("incorrect email or password")
             raise ValueError("incorrect email or password")
         else:
-            _LOGGER.error("call to {} failed with {}".format(function, json))
+            #_LOGGER.error("call to {} failed with {}".format(function, json))
             raise RuntimeError("failure code {} ({}) for call {} and parameters {}".format(
                 json['code'], json['msg'], function, args))
 
     def __call_user_api(self, function, args):
-        _LOGGER.debug("calling user api {} with {}".format(function, args))
+        #_LOGGER.debug("calling user api {} with {}".format(function, args))
         params = {'todo': function}
         params.update(args)
         response = requests.post(EcoVacsAPI.USER_URL_FORMAT.format(continent=self.continent), json=params, verify=self.verify_ssl)
         json = response.json()
-        _LOGGER.debug("got {}".format(json))
+        #_LOGGER.debug("got {}".format(json))
         if json['result'] == 'ok':
             return json
         else:
-            _LOGGER.error("call to {} failed with {}".format(function, json))
+            #_LOGGER.error("call to {} failed with {}".format(function, json))
             raise RuntimeError(
                 "failure {} ({}) for call {} and parameters {}".format(json['error'], json['errno'], function, params))
 
@@ -269,7 +269,7 @@ class EcoVacsAPI:
             params = {}
             params.update(args)
 
-        _LOGGER.debug("calling portal api {} function {} with {}".format(api, function, params))            
+        #_LOGGER.debug("calling portal api {} function {} with {}".format(api, function, params))            
         
         continent = self.continent
         if 'continent' in kwargs:
@@ -280,28 +280,28 @@ class EcoVacsAPI:
         response = requests.post(url, json=params, verify=verify_ssl)        
 
         json = response.json()
-        _LOGGER.debug("got {}".format(json))
+        #_LOGGER.debug("got {}".format(json))
         if api == self.USERSAPI:    
             if json['result'] == 'ok':
-                _LOGGER.debug("RESULT OK")
+                #_LOGGER.debug("RESULT OK")
                 return json
             elif json['result'] == 'fail':
                 if json['error'] == 'set token error.': # If it is a set token error try again
                     if not 'set_token' in kwargs:      
-                        _LOGGER.warning("loginByItToken set token error, trying again (2/3)")              
+                        #_LOGGER.warning("loginByItToken set token error, trying again (2/3)")              
                         return self.__call_portal_api(self.USERSAPI, function, args, verify_ssl=verify_ssl, set_token=1)
                     elif kwargs.get('set_token') == 1:
-                        _LOGGER.warning("loginByItToken set token error, trying again with ww (3/3)")              
+                        #_LOGGER.warning("loginByItToken set token error, trying again with ww (3/3)")              
                         return self.__call_portal_api(self.USERSAPI, function, args, verify_ssl=verify_ssl, set_token=2, continent="ww")
                     else:
-                        _LOGGER.warning("loginByItToken set token error, failed after 3 attempts")
+                        #_LOGGER.warning("loginByItToken set token error, failed after 3 attempts")
                                     
         if api.startswith(self.PRODUCTAPI):
             if json['code'] == 0:
                 return json      
 
         else:
-            _LOGGER.error("call to {} failed with {}".format(function, json))
+            #_LOGGER.error("call to {} failed with {}".format(function, json))
             raise RuntimeError(
                 "failure {} ({}) for call {} and parameters {}".format(json['error'], json['errno'], function, params))
 
@@ -436,7 +436,7 @@ class VacBot():
         self.errorEvents = EventEmitter()
 
         # Map variables
-        self.buffer = np.zeros((1000, 100, 100))
+        self.buffer = np.zeros((64, 100, 100))
         self.mapPieces = []
 
         #Set none for clients to start        
@@ -468,7 +468,7 @@ class VacBot():
 
         if not error == '':
             self.errorEvents.notify(error)
-            _LOGGER.warning("*** error = " + error)
+            #_LOGGER.warning("*** error = " + error)
 
     def _handle_life_span(self, event):
         response = event['body']['data'][0]
@@ -477,7 +477,7 @@ class VacBot():
         try:
             type = COMPONENT_FROM_ECOVACS[type]
         except KeyError:
-            _LOGGER.warning("Unknown component type: '" + type + "'")
+            #_LOGGER.warning("Unknown component type: '" + type + "'")
             
         left = int(response['left'])
         total = int(response['total'])
@@ -488,7 +488,7 @@ class VacBot():
         
         lifespan_event = {'type': type, 'lifespan': lifespan}
         self.lifespanEvents.notify(lifespan_event)
-        _LOGGER.debug("*** life_span " + type + " = " + str(lifespan))
+        #_LOGGER.debug("*** life_span " + type + " = " + str(lifespan))
 
     def _handle_fan_speed(self, event):
         response = event['body']['data']
@@ -497,18 +497,18 @@ class VacBot():
         try:
             speed = FAN_SPEED_FROM_ECOVACS[speed]
         except KeyError:
-            _LOGGER.warning("Unknown fan speed: '" + str(speed) + "'")
+            #_LOGGER.warning("Unknown fan speed: '" + str(speed) + "'")
       
         self.fan_speed = speed
         
         self.fanspeedEvents.notify(speed)
-        _LOGGER.debug("*** fan_speed = {}".format(speed))
+        #_LOGGER.debug("*** fan_speed = {}".format(speed))
 
     def _handle_clean_logs(self, event):
         response = event['logs']
         self.last_clean_image = response[0]['imageUrl']
 
-        _LOGGER.debug(response)
+        #_LOGGER.debug(response)
 
     def _handle_water_info(self, event):
         response = event['body']['data']
@@ -517,11 +517,11 @@ class VacBot():
         try:
             amount = WATER_LEVEL_FROM_ECOVACS[amount]
         except KeyError:
-            _LOGGER.warning("Unknown water level: '" + str(amount) + "'")
+            #_LOGGER.warning("Unknown water level: '" + str(amount) + "'")
       
         self.water_level = amount
         
-        _LOGGER.debug("*** water_level = {}".format(amount))
+        #_LOGGER.debug("*** water_level = {}".format(amount))
 
     def _handle_clean_report(self, event):
         response = event['body']['data']
@@ -552,13 +552,16 @@ class VacBot():
         if len(self.mapPieces) == 0:
             for i in range(64):
                 self.mapPieces.append(str(i) + '-' + str(values[i]))
-                self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
+                if str(values[i]) != '1295764014':
+                    #_LOGGER.debug("NEW MAP PIECE: " + str(i) + ' | ' + str(values[i]))
+                    self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
         else:
             for i in range(64):
                 if self.mapPieces[i] != str(i) + '-' + str(values[i]):
                     self.mapPieces[i] = str(i) + '-' + str(values[i])
-                    _LOGGER.debug("UPDATING MAP PIECE: " + str(i))
-                    self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
+                    if str(values[i]) != '1295764014':
+                        #_LOGGER.debug("UPDATING MAP PIECE: " + str(i))
+                        self.exc_command('getMinorMap', {'mid': response['mid'],'type': 'ol', 'pieceIndex': i})
 
     def _handle_cached_map(self, event):
         response = event['body']['data']
@@ -589,11 +592,11 @@ class VacBot():
         try:
             self.battery_status = response['data']['value']
         except ValueError:
-            _LOGGER.warning("couldn't parse battery status " + response)
+            #_LOGGER.warning("couldn't parse battery status " + response)
         else:
             self.batteryEvents.notify(self.battery_status)
 
-        _LOGGER.debug("*** battery_status = {} %".format(self.battery_status))
+        #_LOGGER.debug("*** battery_status = {} %".format(self.battery_status))
 
     def _handle_charge_state(self, event):
         response = event['body']
@@ -609,12 +612,12 @@ class VacBot():
             elif response['msg'] == 'fail' and response['code'] == '3': #Bot in stuck state, example dust bin out
                 status = 'STATE_ERROR'
             else: 
-                _LOGGER.error("Unknown charging status '" + response['code'] + "'") #Log this so we can identify more errors    
+                #_LOGGER.error("Unknown charging status '" + response['code'] + "'") #Log this so we can identify more errors    
 
         if status != 'none':
             self.vacuum_status = status
             self.statusEvents.notify(self.vacuum_status)
-            _LOGGER.debug("*** vacuum_status = " + self.vacuum_status)
+            #_LOGGER.debug("*** vacuum_status = " + self.vacuum_status)
 
     def _vacuum_address(self):
         return self.vacuum['did'] #IOTMQ only uses the did
@@ -626,15 +629,15 @@ class VacBot():
             else:
                 self.is_available = True
         except XMPPError as err:
-            _LOGGER.warning("Ping did not reach VacBot. Will retry.")
-            _LOGGER.warning("*** Error type: " + err.etype)
-            _LOGGER.warning("*** Error condition: " + err.condition)
+            #_LOGGER.warning("Ping did not reach VacBot. Will retry.")
+            #_LOGGER.warning("*** Error type: " + err.etype)
+            #_LOGGER.warning("*** Error condition: " + err.condition)
             self._failed_pings += 1
             if self._failed_pings >= 4:
                 self.is_available = False
 
         except RuntimeError as err:
-            _LOGGER.warning("Ping did not reach VacBot. Will retry.")
+            #_LOGGER.warning("Ping did not reach VacBot. Will retry.")
             self._failed_pings += 1
             if self._failed_pings >= 4:
                 self.is_available = False
@@ -659,9 +662,9 @@ class VacBot():
             self.exc_command('getCachedMapInfo')
             self.exc_command('GetCleanLogs')
         except XMPPError as err:
-            _LOGGER.warning("Component refresh requests failed to reach VacBot. Will try again later.")
-            _LOGGER.warning("*** Error type: " + err.etype)
-            _LOGGER.warning("*** Error condition: " + err.condition)
+            #_LOGGER.warning("Component refresh requests failed to reach VacBot. Will try again later.")
+            #_LOGGER.warning("*** Error type: " + err.etype)
+            #_LOGGER.warning("*** Error condition: " + err.condition)
 
     def refresh_statuses(self):
         try:
@@ -671,18 +674,18 @@ class VacBot():
             self.exc_command('getSpeed')
             self.exc_command('getWaterInfo')
         except XMPPError as err:
-            _LOGGER.warning("Initial status requests failed to reach VacBot. Will try again on next ping.")
-            _LOGGER.warning("*** Error type: " + err.etype)
-            _LOGGER.warning("*** Error condition: " + err.condition)
+            #_LOGGER.warning("Initial status requests failed to reach VacBot. Will try again on next ping.")
+            #_LOGGER.warning("*** Error type: " + err.etype)
+            #_LOGGER.warning("*** Error condition: " + err.condition)
 
     def refresh_liveMap(self):
         try:
             self.exc_command('getMajorMap')
             self.CreatePNGMap()
         except XMPPError as err:
-            _LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
-            _LOGGER.warning("*** Error type: " + err.etype)
-            _LOGGER.warning("*** Error condition: " + err.condition)
+            #_LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
+            #_LOGGER.warning("*** Error type: " + err.etype)
+            #_LOGGER.warning("*** Error condition: " + err.condition)
 
     def request_all_statuses(self):
         self.refresh_statuses()
@@ -735,7 +738,7 @@ class VacBot():
         self.refresh_statuses()
 
     def exc_command(self, action, params=None, **kwargs):
-        #_LOGGER.debug(params)
+        ##_LOGGER.debug(params)
         self.send_command(VacBotCommand(action, params))
 
     def send_command(self, action):
@@ -786,7 +789,7 @@ class VacBot():
                     imageX += 100
                     imageY = 0
 
-            _LOGGER.debug('PIECE: ' + str(i) + ' X:' + str(imageX) + ' Y:' + str(imageY))
+            #_LOGGER.debug('PIECE: ' + str(i) + ' X:' + str(imageX) + ' Y:' + str(imageY))
 
             for x in range(100):
                 for y in range(100):
@@ -893,18 +896,18 @@ class EcoVacsIOTMQ(ClientMQTT):
 
     def on_connect(self, client, userdata, flags, rc):        
         if rc != 0:
-            _LOGGER.error("EcoVacsMQTT - error connecting with MQTT Return {}".format(rc))
+            #_LOGGER.error("EcoVacsMQTT - error connecting with MQTT Return {}".format(rc))
             raise RuntimeError("EcoVacsMQTT - error connecting with MQTT Return {}".format(rc))
                  
         else:
-            _LOGGER.debug("EcoVacsMQTT - Connected with result code "+str(rc))
-            _LOGGER.debug("EcoVacsMQTT - Subscribing to all")        
+            #_LOGGER.debug("EcoVacsMQTT - Connected with result code "+str(rc))
+            #_LOGGER.debug("EcoVacsMQTT - Subscribing to all")        
 
             self.subscribe('iot/atr/+/' + self.vacuum['did'] + '/' + self.vacuum['class'] + '/' + self.vacuum['resource'] + '/+', qos=0)            
             self.ready_flag.set()
 
     def send_ping(self):
-        _LOGGER.debug("*** MQTT sending ping ***")
+        #_LOGGER.debug("*** MQTT sending ping ***")
         rc = self._send_simple_command(MQTTPublish.paho.PINGREQ)
         if rc == MQTTPublish.paho.MQTT_ERR_SUCCESS:
             return True         
@@ -914,11 +917,11 @@ class EcoVacsIOTMQ(ClientMQTT):
     def send_command(self, action, recipient):
         if action.name.lower() == 'getcleanlogs':
             c = self._wrap_log_command(action, recipient)
-            _LOGGER.debug('Sending command {0}'.format(c))  
+            #_LOGGER.debug('Sending command {0}'.format(c))  
             self._handle_ctl_api(action, self.__call_logs_api(c ,verify_ssl=self.verify_ssl ))
         else:
             c = self._wrap_command(action, recipient)
-            _LOGGER.debug('Sending command {0}'.format(c))  
+            #_LOGGER.debug('Sending command {0}'.format(c))  
             self._handle_ctl_api(action, self.__call_iotdevmanager_api(c ,verify_ssl=self.verify_ssl ))
 
     def _wrap_log_command(self, cmd, recipient):
@@ -971,7 +974,7 @@ class EcoVacsIOTMQ(ClientMQTT):
         }     
 
     def __call_iotdevmanager_api(self, args, verify_ssl=True):
-        _LOGGER.debug("calling iotdevmanager api with {}".format(args))                
+        #_LOGGER.debug("calling iotdevmanager api with {}".format(args))                
         params = {}
         params.update(args)
 
@@ -983,7 +986,7 @@ class EcoVacsIOTMQ(ClientMQTT):
             }
             response = requests.post(url,headers=headers, json=params, timeout=20, verify=verify_ssl) #May think about having timeout as an arg that could be provided in the future
         except requests.exceptions.ReadTimeout:
-            _LOGGER.warning("call to iotdevmanager failed with ReadTimeout")
+            #_LOGGER.warning("call to iotdevmanager failed with ReadTimeout")
             return {}                
         
         json = response.json()
@@ -996,11 +999,11 @@ class EcoVacsIOTMQ(ClientMQTT):
                     return {}
             else:
                 #TODO - Not sure if we want to raise an error yet, just return empty for now
-                _LOGGER.error("call to iotdevmanager failed with {}".format(json))
+                #_LOGGER.error("call to iotdevmanager failed with {}".format(json))
                 return {}
 
     def __call_logs_api(self, args, verify_ssl=True):
-        _LOGGER.debug("calling logs api with {}".format(args))                
+        #_LOGGER.debug("calling logs api with {}".format(args))                
         params = {}
         params.update(args)
 
@@ -1012,7 +1015,7 @@ class EcoVacsIOTMQ(ClientMQTT):
             }
             response = requests.post(url,headers=headers, json=params, timeout=20, verify=verify_ssl) #May think about having timeout as an arg that could be provided in the future
         except requests.exceptions.ReadTimeout:
-            _LOGGER.warning("call to logs failed with ReadTimeout")
+            #_LOGGER.warning("call to logs failed with ReadTimeout")
             return {}                
         
         json = response.json()
@@ -1025,7 +1028,7 @@ class EcoVacsIOTMQ(ClientMQTT):
                     return {}
             else:
                 #TODO - Not sure if we want to raise an error yet, just return empty for now
-                _LOGGER.error("call to logs failed with {}".format(json))
+                #_LOGGER.error("call to logs failed with {}".format(json))
                 return {}
 
     def _handle_ctl_api(self, action, message):
@@ -1044,7 +1047,7 @@ class EcoVacsIOTMQ(ClientMQTT):
         if eventname == 'getcleanlogs':
             jsonstring['event'] = "clean_logs"
         elif jsonstring['body']['msg'] == 'ok':
-            _LOGGER.debug('BEFORE Status:' + eventname)
+            #_LOGGER.debug('BEFORE Status:' + eventname)
             if 'cleaninfo' in eventname:
                 jsonstring['event'] = "clean_report"
             elif 'chargestate' in eventname:
@@ -1068,7 +1071,7 @@ class EcoVacsIOTMQ(ClientMQTT):
             elif 'getwater' in eventname:
                 jsonstring['event'] = "water_info"
             else:
-                _LOGGER.debug('UKNOWN Status:' + eventname)
+                #_LOGGER.debug('UKNOWN Status:' + eventname)
                 return
         else:
             if jsonstring['body']['msg'] == 'fail':
@@ -1078,11 +1081,11 @@ class EcoVacsIOTMQ(ClientMQTT):
             else:
                 return
 
-        _LOGGER.debug("LOGGED EVENT: " + jsonstring['event'])
+        #_LOGGER.debug("LOGGED EVENT: " + jsonstring['event'])
         return jsonstring
 
     def _handle_ctl_mqtt(self, client, userdata, message):
-        #_LOGGER.warning("EcoVacs MQTT Received Message on Topic: {} - Message: {}".format(message.topic, str(message.payload.decode("utf-8"))))
+        ##_LOGGER.warning("EcoVacs MQTT Received Message on Topic: {} - Message: {}".format(message.topic, str(message.payload.decode("utf-8"))))
         as_dict = self._ctl_to_dict_api(message.topic, str(message.payload.decode("utf-8")))
         if as_dict is not None:
             for s in self.ctl_subscribers:
